Documentation
¶
Overview ¶
Package crs provides coordinate reference systems, map projections, and datum transformations.
Index ¶
- Variables
- func ParseVerticalGridTIFF(r io.Reader) (*verticalGridData, error)
- func RegisterDatum(name string, d Datum)
- func RegisterEPSG(code int, c CoordinateReferenceSystem)
- func RegisterGridDir(dir string)
- func RegisterGridFS(prefix string, fsys fs.FS)
- func RegisterSpheroid(name string, s Spheroid)
- func SetGridCDN(uri string, cacheDir ...string)
- type AlbersEqualArea
- type AmericanPolyconic
- type AzimuthalEquidistant
- type BonneSouthOrientated
- type BoundingBox
- type CRS
- type CassiniSoldner
- type ColombiaUrban
- type Conversion
- type CoordinateFrameFullMatrix
- func (m CoordinateFrameFullMatrix) FromTarget(source, target Spheroid, lon0, lat0, h0 float64) (float64, float64, float64, error)
- func (m CoordinateFrameFullMatrix) String() string
- func (m CoordinateFrameFullMatrix) ToTarget(source, target Spheroid, lon, lat, h float64) (float64, float64, float64, error)
- type CoordinateReferenceSystem
- func (crs CoordinateReferenceSystem) AtEpoch(epoch float64) CoordinateReferenceSystem
- func (crs CoordinateReferenceSystem) Intersects(bbox ...BoundingBox) (CoordinateReferenceSystem, error)
- func (crs CoordinateReferenceSystem) String() string
- func (crs CoordinateReferenceSystem) TransformTo(to CoordinateReferenceSystem) Func
- type Datum
- func (d Datum) AtEpoch(epoch float64) Datum
- func (d Datum) FromWGS84(lon0, lat0, h0 float64) (float64, float64, float64, error)
- func (d Datum) Intersects(bbox ...BoundingBox) (Datum, error)
- func (d Datum) String() string
- func (d Datum) ToWGS84(lon, lat, h float64) (float64, float64, float64, error)
- func (d Datum) TransformTo(target Datum, lon, lat, h float64) (float64, float64, float64, error)
- type EqualEarth
- type EquidistantCylindrical
- type Func
- type Geocentric
- type Geographic
- type Geographic3dOffset
- type GeographicOffset
- type GridNotFoundError
- type GuamProjection
- type HorizontalGrid
- func (hg HorizontalGrid) FromTarget(source Spheroid, target Spheroid, lon0 float64, lat0 float64, h0 float64) (float64, float64, float64, error)
- func (hg HorizontalGrid) String() string
- func (hg HorizontalGrid) ToTarget(source Spheroid, target Spheroid, lon float64, lat float64, h float64) (float64, float64, float64, error)
- type HotineObliqueMercatorA
- type HyperbolicCassiniSoldner
- type Inverse
- func (i Inverse) FromTarget(source Spheroid, target Spheroid, lon0 float64, lat0 float64, h0 float64) (float64, float64, float64, error)
- func (i Inverse) String() string
- func (i Inverse) ToTarget(source Spheroid, target Spheroid, lon float64, lat float64, h float64) (float64, float64, float64, error)
- type Krovak
- type KrovakModified
- type LabordeObliqueMercator
- type LambertAzimuthalEqualArea
- type LambertAzimuthalEqualAreaSpherical
- func (cs LambertAzimuthalEqualAreaSpherical) FromGeographic(s Spheroid, lon, lat, h float64) (float64, float64, float64)
- func (cs LambertAzimuthalEqualAreaSpherical) String() string
- func (cs LambertAzimuthalEqualAreaSpherical) ToGeographic(s Spheroid, east, north, h float64) (float64, float64, float64)
- type LambertConformalConic
- type LambertConformalConic1SPVariantB
- type LambertConformalConic2SP
- type LambertConformalConic2SPBelgium
- type LambertConformalConic2SPMichigan
- type LambertConicNearConformal
- type LambertCylindricalEqualArea
- type LambertCylindricalEqualAreaSpherical
- func (cs LambertCylindricalEqualAreaSpherical) FromGeographic(s Spheroid, lon, lat, h float64) (float64, float64, float64)
- func (cs LambertCylindricalEqualAreaSpherical) String() string
- func (cs LambertCylindricalEqualAreaSpherical) ToGeographic(s Spheroid, east, north, h float64) (float64, float64, float64)
- type LocalOrthographic
- type LongitudeRotation
- type MercatorA
- type MercatorB
- type ModifiedAzimuthalEquidistant
- type MolodenskyBadekas
- type NewZealandMapGrid
- type ObliqueStereographic
- type Operation
- type OutOfBoundsError
- type PolarStereographicA
- type PolarStereographicB
- type PolarStereographicC
- type PositionVector
- func (pv PositionVector) FromTarget(source Spheroid, target Spheroid, lon0 float64, lat0 float64, h0 float64) (float64, float64, float64, error)
- func (pc PositionVector) String() string
- func (pv PositionVector) ToTarget(source Spheroid, target Spheroid, lon float64, lat float64, h float64) (float64, float64, float64, error)
- type Spheroid
- func (s Spheroid) A2() float64
- func (s Spheroid) B() float64
- func (s Spheroid) E() float64
- func (s Spheroid) E2() float64
- func (s Spheroid) E4() float64
- func (s Spheroid) E6() float64
- func (s Spheroid) Ei() float64
- func (s Spheroid) Ei2() float64
- func (s Spheroid) Ei3() float64
- func (s Spheroid) Ei4() float64
- func (s Spheroid) F() float64
- func (s Spheroid) F2() float64
- func (s Spheroid) GeocentricToGeographic(x, y, z float64) (lon, lat, h float64)
- func (s Spheroid) GeographicToGeocentric(lon, lat, h float64) (x, y, z float64)
- func (s Spheroid) String() string
- type SwissObliqueMercator
- type TimeDependentPositionVector
- func (t TimeDependentPositionVector) FromTarget(source, target Spheroid, lon0, lat0, h0 float64) (float64, float64, float64, error)
- func (t TimeDependentPositionVector) String() string
- func (t TimeDependentPositionVector) ToTarget(source, target Spheroid, lon, lat, h float64) (float64, float64, float64, error)
- type TimeSpecificPositionVector
- func (t TimeSpecificPositionVector) FromTarget(source, target Spheroid, lon0, lat0, h0 float64) (float64, float64, float64, error)
- func (t TimeSpecificPositionVector) String() string
- func (t TimeSpecificPositionVector) ToTarget(source, target Spheroid, lon, lat, h float64) (float64, float64, float64, error)
- type Transformation
- func (t Transformation) FromDatum(owner Spheroid, lon, lat, h float64) (float64, float64, float64, error)
- func (t Transformation) FromWGS84(source Spheroid, lon0, lat0, h0 float64) (float64, float64, float64, error)
- func (t Transformation) String() string
- func (t Transformation) ToDatum(source Spheroid, lon, lat, h float64) (float64, float64, float64, error)
- func (t Transformation) ToWGS84(source Spheroid, lon, lat, h float64) (float64, float64, float64, error)
- type TransverseMercator
- type TunisiaMiningGrid
- type UnsupportedError
- type VelocityGrid
- type VerticalGrid
- type VerticalOffset
- type VerticalOffsetAndSlope
- type WebMercator
Constants ¶
This section is empty.
Variables ¶
var ( WGS84 = Datum{ Name: "wgs84", Spheroid: Spheroid{ Name: "wgs84", A: 6378137, Fi: 298.257223563, }, } )
var World = BoundingBox{
MinLon: -180,
MinLat: -90,
MaxLon: 180,
MaxLat: 90,
}
Functions ¶
func ParseVerticalGridTIFF ¶
ParseVerticalGridTIFF reads a PROJ vertical/geoid GeoTIFF (GTG).
func RegisterDatum ¶
func RegisterEPSG ¶
func RegisterEPSG(code int, c CoordinateReferenceSystem)
func RegisterGridDir ¶
func RegisterGridDir(dir string)
func RegisterGridFS ¶
func RegisterSpheroid ¶
func SetGridCDN ¶
Types ¶
type AlbersEqualArea ¶
type AlbersEqualArea struct {
Lonf float64
Latf float64
Sp1 float64
Sp2 float64
Eastf float64
Northf float64
}
func (AlbersEqualArea) FromGeographic ¶
func (AlbersEqualArea) String ¶
func (cs AlbersEqualArea) String() string
func (AlbersEqualArea) ToGeographic ¶
type AmericanPolyconic ¶
type AmericanPolyconic struct {
Lonf, Latf, Eastf, Northf float64
}
func (AmericanPolyconic) FromGeographic ¶
func (AmericanPolyconic) String ¶
func (cs AmericanPolyconic) String() string
func (AmericanPolyconic) ToGeographic ¶
type AzimuthalEquidistant ¶
type AzimuthalEquidistant struct {
Lonf, Latf, Eastf, Northf float64
}
func (AzimuthalEquidistant) FromGeographic ¶
func (AzimuthalEquidistant) String ¶
func (cs AzimuthalEquidistant) String() string
func (AzimuthalEquidistant) ToGeographic ¶
type BonneSouthOrientated ¶
type BonneSouthOrientated struct {
Lonf, Latf, Eastf, Northf float64
}
func (BonneSouthOrientated) FromGeographic ¶
func (BonneSouthOrientated) String ¶
func (cs BonneSouthOrientated) String() string
func (BonneSouthOrientated) ToGeographic ¶
type BoundingBox ¶
func (BoundingBox) Area ¶
func (b BoundingBox) Area() float64
func (BoundingBox) Contains ¶
func (b BoundingBox) Contains(lon, lat float64) bool
func (BoundingBox) Intersects ¶
func (b BoundingBox) Intersects(bbox BoundingBox) bool
func (BoundingBox) String ¶
func (b BoundingBox) String() string
type CRS ¶
type CRS interface {
CoordinateReferenceSystem | int | string
}
type CassiniSoldner ¶
type CassiniSoldner struct {
Lonf, Latf, Eastf, Northf float64
}
CassiniSoldner is EPSG method 9806 (PROJ +proj=cass).
func (CassiniSoldner) FromGeographic ¶
func (CassiniSoldner) String ¶
func (cs CassiniSoldner) String() string
func (CassiniSoldner) ToGeographic ¶
type ColombiaUrban ¶
type ColombiaUrban struct {
Lonf, Latf, Eastf, Northf, H0 float64
}
ColombiaUrban is EPSG method 1052 (PROJ +proj=col_urban).
func (ColombiaUrban) FromGeographic ¶
func (ColombiaUrban) String ¶
func (cs ColombiaUrban) String() string
func (ColombiaUrban) ToGeographic ¶
type Conversion ¶
type CoordinateFrameFullMatrix ¶
type CoordinateFrameFullMatrix struct {
Tx, Ty, Tz, Rx, Ry, Rz, Ds float64
}
func (CoordinateFrameFullMatrix) FromTarget ¶
func (CoordinateFrameFullMatrix) String ¶
func (m CoordinateFrameFullMatrix) String() string
type CoordinateReferenceSystem ¶
type CoordinateReferenceSystem struct {
Conversion Conversion
Datum Datum
BoundingBox BoundingBox
}
func Parse ¶
func Parse[C CRS](crs C) (CoordinateReferenceSystem, error)
func (CoordinateReferenceSystem) AtEpoch ¶
func (crs CoordinateReferenceSystem) AtEpoch(epoch float64) CoordinateReferenceSystem
AtEpoch evaluates time-dependent datum operations at the given coordinate epoch (decimal year), mirroring Intersects as a pre-Transform datum rewrite.
func (CoordinateReferenceSystem) Intersects ¶
func (crs CoordinateReferenceSystem) Intersects(bbox ...BoundingBox) (CoordinateReferenceSystem, error)
func (CoordinateReferenceSystem) String ¶
func (crs CoordinateReferenceSystem) String() string
func (CoordinateReferenceSystem) TransformTo ¶
func (crs CoordinateReferenceSystem) TransformTo(to CoordinateReferenceSystem) Func
type Datum ¶
type Datum struct {
Name string
Spheroid Spheroid
Transformations []Transformation
}
func (Datum) AtEpoch ¶
AtEpoch returns a copy of d with time-dependent operations evaluated at epoch (decimal year). TimeDependentPositionVector becomes PositionVector; VelocityGrid with a non-zero Epoch gets Dt = epoch - Epoch.
func (Datum) Intersects ¶
func (d Datum) Intersects(bbox ...BoundingBox) (Datum, error)
type EqualEarth ¶
type EqualEarth struct {
Lonf, Eastf, Northf float64
}
EqualEarth is EPSG method 1078 (PROJ +proj=eqearth). Formulas: IOGP Guidance Note 7-2 3.4.4.
func (EqualEarth) FromGeographic ¶
func (EqualEarth) String ¶
func (cs EqualEarth) String() string
func (EqualEarth) ToGeographic ¶
type EquidistantCylindrical ¶
type EquidistantCylindrical struct {
Lonf, Latf, Sp1, Eastf, Northf float64
}
func (EquidistantCylindrical) FromGeographic ¶
func (EquidistantCylindrical) String ¶
func (cs EquidistantCylindrical) String() string
func (EquidistantCylindrical) ToGeographic ¶
type Func ¶
func TransformAt ¶
func TransformAt[F, T CRS](from F, to T, epoch float64, intersects ...BoundingBox) (Func, error)
TransformAt is Transform with both datums evaluated at epoch (decimal year).
type Geocentric ¶
type Geocentric struct{}
func (Geocentric) FromGeographic ¶
func (Geocentric) String ¶
func (g Geocentric) String() string
func (Geocentric) ToGeographic ¶
type Geographic ¶
type Geographic struct{}
func (Geographic) FromGeographic ¶
func (Geographic) String ¶
func (g Geographic) String() string
func (Geographic) ToGeographic ¶
type Geographic3dOffset ¶
type Geographic3dOffset struct {
Lat float64 // arc-seconds
Lon float64 // arc-seconds
H float64 // metres
}
func (Geographic3dOffset) FromTarget ¶
func (Geographic3dOffset) String ¶
func (o Geographic3dOffset) String() string
type GeographicOffset ¶
func (GeographicOffset) FromTarget ¶
func (GeographicOffset) String ¶
func (o GeographicOffset) String() string
type GridNotFoundError ¶
type GridNotFoundError struct {
Err error
}
func (GridNotFoundError) Error ¶
func (e GridNotFoundError) Error() string
func (GridNotFoundError) Unwrap ¶
func (e GridNotFoundError) Unwrap() error
type GuamProjection ¶
type GuamProjection struct {
Lonf, Latf, Eastf, Northf float64
}
func (GuamProjection) FromGeographic ¶
func (GuamProjection) String ¶
func (cs GuamProjection) String() string
func (GuamProjection) ToGeographic ¶
type HorizontalGrid ¶
type HorizontalGrid string
func (HorizontalGrid) FromTarget ¶
func (HorizontalGrid) String ¶
func (hg HorizontalGrid) String() string
type HotineObliqueMercatorA ¶
type HotineObliqueMercatorA struct {
Lonf, Latf, Alpha, Gamma, Scale, Eastf, Northf float64
}
func (HotineObliqueMercatorA) FromGeographic ¶
func (HotineObliqueMercatorA) String ¶
func (cs HotineObliqueMercatorA) String() string
func (HotineObliqueMercatorA) ToGeographic ¶
type HyperbolicCassiniSoldner ¶
type HyperbolicCassiniSoldner struct {
Lonf, Latf, Eastf, Northf float64
}
func (HyperbolicCassiniSoldner) FromGeographic ¶
func (HyperbolicCassiniSoldner) String ¶
func (cs HyperbolicCassiniSoldner) String() string
func (HyperbolicCassiniSoldner) ToGeographic ¶
type Krovak ¶
type Krovak struct {
Lonf float64
Latf float64
Alpha float64
Scale float64
Eastf float64
Northf float64
}
func (Krovak) FromGeographic ¶
type KrovakModified ¶
type KrovakModified struct {
Lonf, Latf, Alpha, Scale, Eastf, Northf float64
}
func (KrovakModified) FromGeographic ¶
func (KrovakModified) String ¶
func (cs KrovakModified) String() string
func (KrovakModified) ToGeographic ¶
type LabordeObliqueMercator ¶
type LabordeObliqueMercator struct {
Lonf, Latf, Alpha, Scale, Eastf, Northf float64
}
func (LabordeObliqueMercator) FromGeographic ¶
func (LabordeObliqueMercator) String ¶
func (cs LabordeObliqueMercator) String() string
func (LabordeObliqueMercator) ToGeographic ¶
type LambertAzimuthalEqualArea ¶
func (LambertAzimuthalEqualArea) FromGeographic ¶
func (LambertAzimuthalEqualArea) String ¶
func (cs LambertAzimuthalEqualArea) String() string
func (LambertAzimuthalEqualArea) ToGeographic ¶
type LambertAzimuthalEqualAreaSpherical ¶
type LambertAzimuthalEqualAreaSpherical struct {
Lonf, Latf, Eastf, Northf float64
}
func (LambertAzimuthalEqualAreaSpherical) FromGeographic ¶
func (LambertAzimuthalEqualAreaSpherical) String ¶
func (cs LambertAzimuthalEqualAreaSpherical) String() string
func (LambertAzimuthalEqualAreaSpherical) ToGeographic ¶
type LambertConformalConic ¶
type LambertConformalConic struct {
Lonf float64
Latf float64
Scale float64
Eastf float64
Northf float64
}
func (LambertConformalConic) FromGeographic ¶
func (LambertConformalConic) String ¶
func (cs LambertConformalConic) String() string
func (LambertConformalConic) ToGeographic ¶
type LambertConformalConic1SPVariantB ¶
type LambertConformalConic1SPVariantB struct {
Lonf, Lat0, Latf, Scale, Eastf, Northf float64
}
LambertConformalConic1SPVariantB is EPSG method 1102. Same cone as LCC 1SP at Lat0 (natural origin); FE/FN apply at Latf (false origin).
func (LambertConformalConic1SPVariantB) FromGeographic ¶
func (LambertConformalConic1SPVariantB) String ¶
func (cs LambertConformalConic1SPVariantB) String() string
func (LambertConformalConic1SPVariantB) ToGeographic ¶
type LambertConformalConic2SP ¶
type LambertConformalConic2SP struct {
Lonf float64
Latf float64
Sp1 float64
Sp2 float64
Eastf float64
Northf float64
}
func (LambertConformalConic2SP) FromGeographic ¶
func (LambertConformalConic2SP) String ¶
func (cs LambertConformalConic2SP) String() string
func (LambertConformalConic2SP) ToGeographic ¶
type LambertConformalConic2SPBelgium ¶
type LambertConformalConic2SPBelgium struct {
Lonf, Latf, Sp1, Sp2, Eastf, Northf float64
}
func (LambertConformalConic2SPBelgium) FromGeographic ¶
func (LambertConformalConic2SPBelgium) String ¶
func (cs LambertConformalConic2SPBelgium) String() string
func (LambertConformalConic2SPBelgium) ToGeographic ¶
type LambertConformalConic2SPMichigan ¶
type LambertConformalConic2SPMichigan struct {
Lonf, Latf, Sp1, Sp2, Eastf, Northf float64
}
func (LambertConformalConic2SPMichigan) FromGeographic ¶
func (LambertConformalConic2SPMichigan) String ¶
func (cs LambertConformalConic2SPMichigan) String() string
func (LambertConformalConic2SPMichigan) ToGeographic ¶
type LambertConicNearConformal ¶
type LambertConicNearConformal struct {
Lonf, Latf, Scale, Eastf, Northf float64
}
func (LambertConicNearConformal) FromGeographic ¶
func (LambertConicNearConformal) String ¶
func (cs LambertConicNearConformal) String() string
func (LambertConicNearConformal) ToGeographic ¶
type LambertCylindricalEqualArea ¶
type LambertCylindricalEqualArea struct {
Lonf, Sp1, Eastf, Northf float64
}
func (LambertCylindricalEqualArea) FromGeographic ¶
func (LambertCylindricalEqualArea) String ¶
func (cs LambertCylindricalEqualArea) String() string
func (LambertCylindricalEqualArea) ToGeographic ¶
type LambertCylindricalEqualAreaSpherical ¶
type LambertCylindricalEqualAreaSpherical struct {
Lonf, Sp1, Eastf, Northf float64
}
func (LambertCylindricalEqualAreaSpherical) FromGeographic ¶
func (LambertCylindricalEqualAreaSpherical) String ¶
func (cs LambertCylindricalEqualAreaSpherical) String() string
func (LambertCylindricalEqualAreaSpherical) ToGeographic ¶
type LocalOrthographic ¶
type LocalOrthographic struct {
Lonf, Latf, Azimuth, Scale, Eastf, Northf float64
}
func (LocalOrthographic) FromGeographic ¶
func (LocalOrthographic) String ¶
func (cs LocalOrthographic) String() string
func (LocalOrthographic) ToGeographic ¶
type LongitudeRotation ¶
type LongitudeRotation struct {
Lon float64
}
func (LongitudeRotation) FromTarget ¶
func (LongitudeRotation) String ¶
func (l LongitudeRotation) String() string
type MercatorA ¶
type MercatorA struct {
Lonf, Latf, Scale, Eastf, Northf float64
}
MercatorA is EPSG method 9804 (PROJ +proj=merc with k / 1SP). Latf is unused in the formulas (natural origin is on the equator).
func (MercatorA) FromGeographic ¶
type MercatorB ¶
type MercatorB struct {
Lonf, Sp1, Eastf, Northf float64
}
MercatorB is EPSG method 9805 (PROJ +proj=merc with lat_ts / 2SP). Sp1 is the latitude of the first standard parallel; k0 is derived from it.
func (MercatorB) FromGeographic ¶
type ModifiedAzimuthalEquidistant ¶
type ModifiedAzimuthalEquidistant struct {
Lonf, Latf, Eastf, Northf float64
}
func (ModifiedAzimuthalEquidistant) FromGeographic ¶
func (ModifiedAzimuthalEquidistant) String ¶
func (cs ModifiedAzimuthalEquidistant) String() string
func (ModifiedAzimuthalEquidistant) ToGeographic ¶
type MolodenskyBadekas ¶
func (MolodenskyBadekas) FromTarget ¶
func (MolodenskyBadekas) String ¶
func (m MolodenskyBadekas) String() string
type NewZealandMapGrid ¶
type NewZealandMapGrid struct {
Lonf, Latf, Eastf, Northf float64
}
func (NewZealandMapGrid) FromGeographic ¶
func (NewZealandMapGrid) String ¶
func (cs NewZealandMapGrid) String() string
func (NewZealandMapGrid) ToGeographic ¶
type ObliqueStereographic ¶
type ObliqueStereographic struct {
Lonf, Latf, Scale, Eastf, Northf float64
}
func (ObliqueStereographic) FromGeographic ¶
func (ObliqueStereographic) String ¶
func (cs ObliqueStereographic) String() string
func (ObliqueStereographic) ToGeographic ¶
type OutOfBoundsError ¶
type OutOfBoundsError struct {
Err error
}
func (OutOfBoundsError) Error ¶
func (e OutOfBoundsError) Error() string
func (OutOfBoundsError) Unwrap ¶
func (e OutOfBoundsError) Unwrap() error
type PolarStereographicA ¶
type PolarStereographicA struct {
Lonf, Latf, Scale, Eastf, Northf float64
}
func (PolarStereographicA) FromGeographic ¶
func (PolarStereographicA) String ¶
func (cs PolarStereographicA) String() string
func (PolarStereographicA) ToGeographic ¶
type PolarStereographicB ¶
type PolarStereographicB struct {
Lonf, Latf, Eastf, Northf float64
}
func (PolarStereographicB) FromGeographic ¶
func (PolarStereographicB) String ¶
func (cs PolarStereographicB) String() string
func (PolarStereographicB) ToGeographic ¶
type PolarStereographicC ¶
type PolarStereographicC struct {
Lonf, Latf, Eastf, Northf float64
}
PolarStereographicC is EPSG method 9830. Latf is the standard parallel (latitude of false origin); FE/FN apply there, not at the pole.
func (PolarStereographicC) FromGeographic ¶
func (PolarStereographicC) String ¶
func (cs PolarStereographicC) String() string
func (PolarStereographicC) ToGeographic ¶
type PositionVector ¶
type PositionVector struct {
Tx float64
Ty float64
Tz float64
Rx float64
Ry float64
Rz float64
Ds float64
}
func (PositionVector) FromTarget ¶
func (PositionVector) String ¶
func (pc PositionVector) String() string
type SwissObliqueMercator ¶
type SwissObliqueMercator struct {
Lonf float64
Latf float64
Scale float64
Eastf float64
Northf float64
Alpha float64
Gamma float64
}
SwissObliqueMercator is EPSG method 9814 (PROJ +proj=somerc). Alpha/Gamma are retained for EPSG parameter round-trip; the classic Swiss formulas assume azimuth = rectified grid angle = 90°.
func (SwissObliqueMercator) FromGeographic ¶
func (SwissObliqueMercator) String ¶
func (cs SwissObliqueMercator) String() string
func (SwissObliqueMercator) ToGeographic ¶
type TimeDependentPositionVector ¶
type TimeDependentPositionVector struct {
Tx, Ty, Tz, Rx, Ry, Rz, Ds float64
TxRate, TyRate, TzRate, RxRate, RyRate, RzRate, DsRate float64
ReferenceEpoch float64
}
func (TimeDependentPositionVector) FromTarget ¶
func (t TimeDependentPositionVector) FromTarget(source, target Spheroid, lon0, lat0, h0 float64) (float64, float64, float64, error)
FromTarget evaluates Helmert parameters at ReferenceEpoch (dt=0). Use Datum.AtEpoch / TransformAt so rates apply at a coordinate epoch.
func (TimeDependentPositionVector) String ¶
func (t TimeDependentPositionVector) String() string
func (TimeDependentPositionVector) ToTarget ¶
func (t TimeDependentPositionVector) ToTarget(source, target Spheroid, lon, lat, h float64) (float64, float64, float64, error)
ToTarget evaluates Helmert parameters at ReferenceEpoch (dt=0). Use Datum.AtEpoch / TransformAt so rates apply at a coordinate epoch.
type TimeSpecificPositionVector ¶
type TimeSpecificPositionVector struct {
Tx, Ty, Tz, Rx, Ry, Rz, Ds float64
TransformationEpoch float64
}
func (TimeSpecificPositionVector) FromTarget ¶
func (TimeSpecificPositionVector) String ¶
func (t TimeSpecificPositionVector) String() string
type Transformation ¶
type Transformation struct {
Target *Datum
Accuracy float64
BoundingBox BoundingBox
Operation Operation
}
func (Transformation) String ¶
func (t Transformation) String() string
type TransverseMercator ¶
type TransverseMercator struct {
Lonf float64
Latf float64
Scale float64
Eastf float64
Northf float64
ZoneWidth float64
}
func (TransverseMercator) FromGeographic ¶
func (TransverseMercator) String ¶
func (cs TransverseMercator) String() string
func (TransverseMercator) ToGeographic ¶
type TunisiaMiningGrid ¶
type TunisiaMiningGrid struct {
Lonf, Latf, Eastf, Northf float64
}
func (TunisiaMiningGrid) FromGeographic ¶
func (TunisiaMiningGrid) String ¶
func (cs TunisiaMiningGrid) String() string
func (TunisiaMiningGrid) ToGeographic ¶
type UnsupportedError ¶
type UnsupportedError struct {
Err error
}
func (UnsupportedError) Error ¶
func (e UnsupportedError) Error() string
func (UnsupportedError) Unwrap ¶
func (e UnsupportedError) Unwrap() error
type VelocityGrid ¶
VelocityGrid is PROJ +proj=deformation with a fixed timespan dt (years). Grid bands are east/north/up velocities in mm/year (GTG TYPE=VELOCITY). When Epoch != 0, Datum.AtEpoch sets Dt = epoch - Epoch.
func (VelocityGrid) FromTarget ¶
func (v VelocityGrid) FromTarget(source, target Spheroid, lon0, lat0, h0 float64) (float64, float64, float64, error)
FromTarget implements Operation: apply −dt · V.
func (VelocityGrid) String ¶
func (v VelocityGrid) String() string
type VerticalGrid ¶
type VerticalGrid string
VerticalGrid is a geoid / vertical undulation grid (PROJ vgridshift / GTG). Grid samples are the geographic→vertical offset δ (metres): H = h + δ. For a classical geoid undulation N (H = h − N), the grid stores δ = −N.
func (VerticalGrid) FromTarget ¶
func (vg VerticalGrid) FromTarget(source, target Spheroid, lon0, lat0, h0 float64) (float64, float64, float64, error)
FromTarget implements Operation: ellipsoidal → orthometric (H = h + δ).
func (VerticalGrid) String ¶
func (vg VerticalGrid) String() string
type VerticalOffset ¶
type VerticalOffset struct {
Dh float64
}
func (VerticalOffset) FromTarget ¶
func (VerticalOffset) String ¶
func (o VerticalOffset) String() string
type VerticalOffsetAndSlope ¶
type VerticalOffsetAndSlope struct {
Lat0, Lon0 float64
Dh float64
SlopeLat, SlopeLon float64 // arc-seconds
}
func (VerticalOffsetAndSlope) FromTarget ¶
func (o VerticalOffsetAndSlope) FromTarget(source, target Spheroid, lon0, lat0, h0 float64) (float64, float64, float64, error)
FromTarget implements Operation.
func (VerticalOffsetAndSlope) String ¶
func (o VerticalOffsetAndSlope) String() string
type WebMercator ¶
func (WebMercator) FromGeographic ¶
func (WebMercator) String ¶
func (cs WebMercator) String() string
func (WebMercator) ToGeographic ¶
Source Files
¶
- aea.go
- aeqd.go
- bbox.go
- bonne.go
- cassini.go
- colombia_urban.go
- crs.go
- datum.go
- datum_path.go
- epsg_loader.go
- eqc.go
- equal_earth.go
- error.go
- geocentric.go
- geographic.go
- geographic_ops.go
- helmert_exact.go
- helper.go
- horizontal_grid.go
- hotine.go
- hyperbolic_cassini.go
- krovak.go
- krovak_modified.go
- laborde.go
- laea.go
- laea_spherical.go
- lcc.go
- lcc1sp_variant_b.go
- lcc2sp.go
- lcc2sp_belgium.go
- lcc2sp_michigan.go
- lcca.go
- lcea.go
- local_ortho.go
- mercator.go
- modified_aeqd.go
- molodensky_badekas.go
- ntv2_grid.go
- ntv2_gsb.go
- ntv2_tif.go
- nzmg.go
- oblique_stereo.go
- parse.go
- polar_stereo.go
- polyconic.go
- position_vector.go
- som.go
- spheroid.go
- spheroid_loader.go
- time_ops.go
- tmerc.go
- transformation.go
- tunisia.go
- velocity_grid.go
- vertical_grid.go
- vertical_offset.go
- webmercator.go